summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/mon-stuff.cc
diff options
context:
space:
mode:
authorDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2009-11-19 05:55:49 -0600
committerDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2009-11-19 06:31:39 -0600
commitad599ad1c85be1ffba72f5aacacf869fa85010ca (patch)
tree40ee99cb940687ed21de444be1bbf78003b3316f /crawl-ref/source/mon-stuff.cc
parentb1aaf507f2ecb50a7792037b1f9894e06591ce3d (diff)
downloadcrawl-ref-ad599ad1c85be1ffba72f5aacacf869fa85010ca.tar.gz
crawl-ref-ad599ad1c85be1ffba72f5aacacf869fa85010ca.zip
Split chaotic things into unclean and chaotic things.
Chaotic things are now shapeshifters, mutators, etc., while unclean things are diseasing things, rotting things, etc. Zin still hates both. As good gods treat both unholy and evil monsters as evil, he'll treat both unclean and chaotic monsters as chaotic. Note that silver will only do extra damage to chaotics, as before.
Diffstat (limited to 'crawl-ref/source/mon-stuff.cc')
-rw-r--r--crawl-ref/source/mon-stuff.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/crawl-ref/source/mon-stuff.cc b/crawl-ref/source/mon-stuff.cc
index 030d5e0a0c..f43a814030 100644
--- a/crawl-ref/source/mon-stuff.cc
+++ b/crawl-ref/source/mon-stuff.cc
@@ -1655,8 +1655,8 @@ int monster_die(monsters *monster, killer_type killer,
monster->hit_dice, true, monster);
}
- // Zin hates chaotic beings.
- if (monster->is_chaotic())
+ // Zin hates unclean and chaotic beings.
+ if (monster->is_unclean() || monster->is_chaotic())
{
did_god_conduct(DID_KILL_CHAOTIC,
monster->hit_dice, true, monster);